# Itch.io Free Games

## Active sales

Name | Sale end (UTC) |  |  |  |
--- | --- | --- | --- | --- | ---
$active_sales_rows

## Upcoming sales

Name | Sale start (UTC) |  |  |  |
--- | --- | --- | --- | --- | ---
$upcoming_sales_rows

## Last update

$last_update (UTC)

Last checked sale: $last_sale

## Legend

🌐: Game URL on itch.io

📜: Details about the game in JSON format

✔: Claimable game

❌: Download only game

🕑: Claimability unknown

🥇: First time on sale

## Source Code

https://github.com/Smart123s/ItchClaim

## Data in JSON format

📑 Active sales

📑 Upcoming sales

📑 Every sale

## Legal

Copyright (c) 2022-2025 Péter Tombor.
Released under The MIT License (MIT)
Please read the full license.

Game and sales data are collected from itch.io.
The data shown on this site may be inaccurate.
Please read the license for legal disclaimers.
This site is not affiliated with Itch Corp.